lilypondfiletools.AttributedBlock
=================================

.. abjad-lineage:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock

.. autoclass:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.append
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.count
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.extend
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.index
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.insert
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.is_formatted_when_empty
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.pop
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.remove
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.reverse
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.sort
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__add__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__contains__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__delitem__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__delslice__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__eq__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__format__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__ge__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__getitem__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__getslice__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__gt__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__iadd__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__imul__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__iter__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__le__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__len__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__lt__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__mul__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__ne__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__repr__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__reversed__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__rmul__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__setitem__
      ~abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__setslice__

Bases
-----

- :py:class:`__builtin__.list <list>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read/write properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.is_formatted_when_empty
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.append
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.count
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.extend
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.index
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.insert
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.pop
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.remove
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.reverse
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__add__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__contains__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__delitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__delslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__getslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__iadd__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__imul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__iter__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__len__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__mul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__reversed__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__rmul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__setitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.__setslice__
   :noindex:
